use milly::dom::element::Element;
use milly::into;

macro_rules! doc {
    ($title: expr, $lang: expr) => {
        {
            use milly::dom::document::Document;
            use milly::dom::element::Element;
            let mut d = Document::new($lang);
            d.head
                .set_title($title)
                .add_css("https://cdn.jsdelivr.net/npm/@picocss/pico@1/css/pico.min.css")
                .add_element(
                    Element::new("meta")
                        .set_attribute("name", "viewport")
                        .set_attribute("content", "width=device-width,initial-scale=1")
                        .clone()
                );
            d.body
                .append_child(
                    Element::new("nav")
                        .add_class("container-fluid")
                        .append_child(
                            Element::new("ul")
                            .set_id("nav-titles")
                            .append_child(Element::new("li").append_child(
                                $title
                            ))
                        )
                )
                .append_child(
                    Element::new("main")
                        .set_id("main")
                        .add_class("container")
                );
            d
        }
    }
}

fn main() {
    let mut doc = doc!("Main", "en");

    doc.body
        .get_element_by_id("main")
        .unwrap()
        .append_child(
            Element::new("h1")
                .append_child("Hello")
        );

    println!("{}", into!(Element, doc).to_string());
}
